/**
 * @function doReset
 */
"use strict";

const Promise = require('apemanpromise');

/** @lends doReset */
function doReset(Sign, Recover, digest, token, password) {
    return Recover
        .findOne({
            where: {
                recover_token: token,
                recovered: false
            }
        })
        .then(recover => {
            if (!recover) {
                return null;
            }
            let expired = new Date() < new Date(recover.expire_at);
            if (expired) {
                return null;
            }
            return Sign
                .findAll({
                    user_id: recover.user_id
                })
                .then(signs =>
                    Promise.all(
                        signs.map(sign =>
                            digest(password || sign.password, sign.password_salt)
                                .then(hash =>
                                    sign.update({
                                        password_hash: hash,
                                        signmod_at: new Date()
                                    })
                                )
                        )
                    )
                )
                .then(() =>
                    recover.update({
                        recovered: true,
                        recovered_at: new Date()
                    })
                )
        });
}

module.exports = doReset;
